package com.sun.tools.javap.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "21.0.3+9-LTS" },
            { "jdk", "21.0.3" },
            { "release", "21.0.3" },
        };
    }
}
